[![test](https://github.com/snok/asgi-correlation-id/actions/workflows/test.yml/badge.svg)](https://github.com/snok/asgi-correlation-id/actions/workflows/test.yml)
[![codecov](https://codecov.io/gh/snok/asgi-correlation-id/branch/master/graph/badge.svg?token=1aXlWPm2gb)](https://codecov.io/gh/snok/asgi-correlation-id)
[![pypi](https://pypi.org/pypi/asgi-correlation-id)](https://github.com/snok/asgi-correlation-id)


# ASGI Correlation ID middleware

This is a rewrite of [django-guid](django-guid) for ASGI apps.
